%global _with_test 0

Summary:        High-performance memory object caching system
Name:           memcached
Version:        1.6.38
Release:        %mkrel 2
License:        BSD
Group:          System/Servers
URL:            https://memcached.org/
Source0:        https://memcached.org/files/%{name}-%{version}.tar.gz
Source1:        %{name}-tmpfiles.conf
Source2:        memcached.sysconfig
Source3:        memcached.logrotate
Source4:        memcached@.service
Source5:        memcached.target
Requires(post):  systemd >= %{systemd_required_version}
Requires(post):  rpm-helper >= 0.24.8-1
Requires(preun): rpm-helper >= 0.24.8-1
Requires:       cyrus-sasl sasl-plug-plain sasl-plug-crammd5
BuildRequires:  autoconf2.5
BuildRequires:  automake
BuildRequires:  doxygen
BuildRequires:  pkgconfig(libevent)
BuildRequires:  pkgconfig(libsasl2)
BuildRequires:  cyrus-sasl
BuildRequires:  sasl-plug-plain
BuildRequires:  sasl-plug-crammd5
# Required by test suite
BuildRequires:  sasl-plug-sasldb
BuildRequires:  libxslt-proc
BuildRequires:  perl-devel

%description
memcached is a flexible memory object caching daemon designed to alleviate
database load in dynamic web applications by storing objects in memory. It's
based on libevent to scale to any size needed, and is  specifically optimized
to avoid swapping and always use non-blocking I/O.

%package        devel
Summary:        Files needed for development using memcached protocol
Group:          Development/C
Requires:       %{name} = %{version}-%{release}

%description    devel
Install memcached-devel if you are developing C/C++ applications that require
access to the memcached binary include files.

%prep
%setup -q

%build
%serverbuild

%configure \
%ifarch x86_64
--enable-extstore \
--enable-64bit
%endif
#disable extstore on 32bit, due to bug #319 (github)

#--enable-sasl
%make_build
make docs

%if %_with_test
%check
export PATH="$PATH:/sbin:/usr/sbin"
# whitespace tests fail locally on fedpkg systems now that they use git
rm -f t/whitespace.t

# Parts of the test suite only succeed as non-root.
if [ `id -u` -ne 0 ]; then
  # remove failing test that doesn't work in
  # build systems
  rm -f t/daemonize.t
fi
make test
%endif

%install
%makeinstall

install -m644 %{SOURCE1} -D %{buildroot}%{_tmpfilesdir}/%{name}.conf
install -m644 %{SOURCE2} -D %{buildroot}%{_sysconfdir}/sysconfig/%{name}
install -m644 %{SOURCE3} -D %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
install -m755 scripts/%{name}-tool %{buildroot}%{_bindir}/%{name}-tool

install -m644 %{SOURCE4} -D %{buildroot}%{_unitdir}/%{name}@.service
install -m644 %{SOURCE5} -D %{buildroot}%{_unitdir}/%{name}.target

%post
%_tmpfilescreate %{name}
%_post_service %{name} %{name}.target

%preun
%_preun_service %{name} %{name}.target

%pre
%_pre_useradd %{name} /dev/null /bin/false

%postun
%_postun_userdel %{name}

%files
%doc AUTHORS* COPYING ChangeLog NEWS
%doc doc/CONTRIBUTORS doc/protocol.txt doc/readme.txt
%config(noreplace) %{_sysconfdir}/sysconfig/%{name}
%config(noreplace) %{_sysconfdir}/logrotate.d/%{name}
%{_bindir}/%{name}-tool
%{_bindir}/%{name}
%{_tmpfilesdir}/%{name}.conf
%{_unitdir}/%{name}*.service
%{_unitdir}/%{name}.target
%{_mandir}/man1/%{name}.1*

%files devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h


%changelog
* Mon Jul 07 2025 umeabot <umeabot> 1.6.38-2.mga10
+ Revision: 2248934
- Mageia 10 Mass Rebuild

* Thu Mar 20 2025 mokraemer <mokraemer> 1.6.38-1.mga10
+ Revision: 2167192
- new version 1.6.38

* Fri Feb 21 2025 mokraemer <mokraemer> 1.6.37-1.mga10
+ Revision: 2150210
- new version 1.6.37

* Wed Feb 05 2025 mokraemer <mokraemer> 1.6.36-1.mga10
+ Revision: 2145361
- new version 1.6.36

* Sun Feb 02 2025 mokraemer <mokraemer> 1.6.35-1.mga10
+ Revision: 2144676
- new version 1.6.35

* Sat Dec 28 2024 mokraemer <mokraemer> 1.6.34-1.mga10
+ Revision: 2130849
- new version 1.6.34

* Tue Dec 10 2024 mokraemer <mokraemer> 1.6.33-1.mga10
+ Revision: 2123375
- memcached 1.6.33

* Wed Oct 23 2024 mokraemer <mokraemer> 1.6.32-1.mga10
+ Revision: 2110762
- new version 1.6.32

* Sun Sep 08 2024 mokraemer <mokraemer> 1.6.31-1.mga10
+ Revision: 2094531
- new version 1.6.31

* Mon Jul 01 2024 mokraemer <mokraemer> 1.6.29-1.mga10
+ Revision: 2078350
- new version 1.6.29

* Sun Jun 09 2024 mokraemer <mokraemer> 1.6.28-1.mga10
+ Revision: 2071802
- new version 1.6.28

* Thu May 09 2024 mokraemer <mokraemer> 1.6.27-1.mga10
+ Revision: 2063188
- new version 1.6.27

* Wed Mar 27 2024 mokraemer <mokraemer> 1.6.26-1.mga10
+ Revision: 2052833
- new version 1.6.26

* Tue Mar 19 2024 mokraemer <mokraemer> 1.6.25-1.mga10
+ Revision: 2050953
- new version 1.6.25

* Wed Feb 28 2024 mokraemer <mokraemer> 1.6.24-1.mga10
+ Revision: 2045327
- new version 1.6.24

* Wed Jan 10 2024 mokraemer <mokraemer> 1.6.23-1.mga10
+ Revision: 2029465
- new version 1.6.23

* Mon Oct 16 2023 mokraemer <mokraemer> 1.6.22-1.mga10
+ Revision: 1997254
- new version 1.6.22

* Fri Jun 16 2023 mokraemer <mokraemer> 1.6.21-1.mga9
+ Revision: 1962085
- new version 1.6.21

* Sat May 13 2023 mokraemer <mokraemer> 1.6.20-1.mga9
+ Revision: 1956764
- new version 1.6.20
- new release 1.6.19

* Thu Jan 12 2023 mokraemer <mokraemer> 1.6.18-1.mga9
+ Revision: 1932505
- new version 1.6.18

* Mon Aug 29 2022 mokraemer <mokraemer> 1.6.17-1.mga9
+ Revision: 1881617
- new version 1.6.17

* Thu Aug 04 2022 mokraemer <mokraemer> 1.6.16-1.mga9
+ Revision: 1875047
- new version 1.6.16

* Wed Mar 30 2022 mokraemer <mokraemer> 1.6.15-1.mga9
+ Revision: 1834625
- new version 1.6.15

* Tue Mar 29 2022 umeabot <umeabot> 1.6.14-2.mga9
+ Revision: 1833212
- Mageia 9 Mass Rebuild

* Thu Feb 10 2022 mokraemer <mokraemer> 1.6.14-1.mga9
+ Revision: 1772806
- new version 1.6.14

* Thu Jan 13 2022 mokraemer <mokraemer> 1.6.13-1.mga9
+ Revision: 1768220
- new version 1.6.13

* Wed Sep 29 2021 mokraemer <mokraemer> 1.6.12-1.mga9
+ Revision: 1746851
- new version 1.6.12
- new version 1.6.11

* Thu Jul 29 2021 mokraemer <mokraemer> 1.6.10-1.mga9
+ Revision: 1738117
- new version 1.6.10

* Fri Nov 27 2020 tmb <tmb> 1.6.9-2.mga9
+ Revision: 1649791
- rebuild for missing signatures

* Sat Nov 21 2020 mokraemer <mokraemer> 1.6.9-1.mga8
+ Revision: 1648083
- new version 1.6.9

* Tue Oct 27 2020 mokraemer <mokraemer> 1.6.8-1.mga8
+ Revision: 1639814
- new version 1.6.8

* Sat Sep 05 2020 mokraemer <mokraemer> 1.6.7-1.mga8
+ Revision: 1622389
- new version 1.6.7

* Wed May 13 2020 mokraemer <mokraemer> 1.6.6-1.mga8
+ Revision: 1583510
- new version 1.6.6

* Tue May 12 2020 mokraemer <mokraemer> 1.6.5-1.mga8
+ Revision: 1583379
- new version 1.6.5

* Tue Apr 14 2020 mokraemer <mokraemer> 1.6.4-1.mga8
+ Revision: 1567246
- new version 1.6.4

* Mon Mar 30 2020 mokraemer <mokraemer> 1.6.3-1.mga8
+ Revision: 1562335
- new version 1.6.3

* Mon Mar 23 2020 mokraemer <mokraemer> 1.6.2-1.mga8
+ Revision: 1559138
- new version 1.6.2

* Tue Mar 17 2020 mokraemer <mokraemer> 1.6.1-1.mga8
+ Revision: 1557293
- new version 1.6.1

* Mon Mar 09 2020 mokraemer <mokraemer> 1.6.0-1.mga8
+ Revision: 1555049
- new version 1.6.0

* Thu Feb 20 2020 umeabot <umeabot> 1.5.22-2.mga8
+ Revision: 1546418
- Mageia 8 Mass Rebuild

* Sun Feb 02 2020 mokraemer <mokraemer> 1.5.22-1.mga8
+ Revision: 1486449
- new version 1.5.22

* Wed Jan 22 2020 mokraemer <mokraemer> 1.5.21-1.mga8
+ Revision: 1481996
- new version  1.5.21
+ wally <wally>
- replace deprecated %%configure2_5x

* Wed Nov 13 2019 mokraemer <mokraemer> 1.5.20-1.mga8
+ Revision: 1459817
- new version 1.5.20

* Tue Oct 01 2019 mokraemer <mokraemer> 1.5.19-1.mga8
+ Revision: 1448694
- new version 1.5.19

* Sun Sep 29 2019 mokraemer <mokraemer> 1.5.18-1.mga8
+ Revision: 1447929
- new release 1.5.18

* Fri Aug 30 2019 mokraemer <mokraemer> 1.5.17-1.mga8
+ Revision: 1435199
- new version 1.5.17

* Sun Aug 11 2019 mokraemer <mokraemer> 1.5.16-1.mga8
+ Revision: 1428834
- new version 1.5.16

* Sun Sep 16 2018 mokraemer <mokraemer> 1.5.10-1.mga7
+ Revision: 1259184
- new version 1.5.10

* Sat Jul 14 2018 mokraemer <mokraemer> 1.5.9-1.mga7
+ Revision: 1243632
- new version 1.5.9

* Tue May 29 2018 mokraemer <mokraemer> 1.5.8-1.mga7
+ Revision: 1232886
- new version 1.5.8

* Sun Apr 01 2018 mokraemer <mokraemer> 1.5.7-1.mga7
+ Revision: 1214092
- new version 1.5.7

* Sun Mar 04 2018 mokraemer <mokraemer> 1.5.6-1.mga7
+ Revision: 1206572
- new version 1.5.6
- disabled UDP-Port (mga#22688)

* Sat Dec 30 2017 mokraemer <mokraemer> 1.5.4-1.mga7
+ Revision: 1187415
- enable experimental extstore only on 64bit
- new version with enabled 64Bit support, enabled experimental external-storage (flash)

* Sat Nov 25 2017 shlomif <shlomif> 1.5.3-1.mga7
+ Revision: 1179242
- New version 1,5 (thanks to kekePower)

* Mon Feb 13 2017 mrambo3501 <mrambo3501> 1.4.25-2.mga6
+ Revision: 1085989
- rebuild for new libevent

* Wed Nov 16 2016 neoclust <neoclust> 1.4.25-1.mga6
+ Revision: 1067548
- New version 1.4.25 + fix CVE-2016-870[4-6]

* Fri Feb 12 2016 umeabot <umeabot> 1.4.24-2.mga6
+ Revision: 956147
- Mageia 6 Mass Rebuild

* Thu Sep 10 2015 neoclust <neoclust> 1.4.24-1.mga6
+ Revision: 875324
- New version 1.4.24

* Wed Oct 15 2014 umeabot <umeabot> 1.4.17-3.mga5
+ Revision: 740976
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.4.17-2.mga5
+ Revision: 682352
- Mageia 5 Mass Rebuild

* Tue Jan 14 2014 oden <oden> 1.4.17-1.mga4
+ Revision: 566539
- 1.4.17 (fixes CVE-2013-0179, CVE-2013-7239, CVE-2013-7290, CVE-2013-7291)

* Mon Dec 30 2013 luigiwalser <luigiwalser> 1.4.15-6.mga4
+ Revision: 563337
- add upstream patch to fix CVE-2013-7239

* Fri Nov 22 2013 oden <oden> 1.4.15-3.mga4
+ Revision: 552293
- P0: security fix for CVE-2011-4971

* Mon Oct 21 2013 umeabot <umeabot> 1.4.15-2.mga4
+ Revision: 540662
- Mageia 4 Mass Rebuild

* Wed Oct 09 2013 dlucio <dlucio> 1.4.15-1.mga4
+ Revision: 494128
- filelist fix
- 1.4.15

* Sun Mar 24 2013 colin <colin> 1.4.13-7.mga3
+ Revision: 404859
- Add systemd requires and general post/pre fixes (mga#9302)

* Sat Jan 12 2013 umeabot <umeabot> 1.4.13-6.mga3
+ Revision: 359938
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Nov 25 2012 colin <colin> 1.4.13-5.mga3
+ Revision: 321726
- Use new macros for tmpfiles
- No need to pass in the templated unit name to the post_service helper

* Mon Aug 20 2012 colin <colin> 1.4.13-4.mga3
+ Revision: 282506
- Switch the .target to PartOf= rather than BindTo= now that we have systemd >= 188

* Mon Jul 23 2012 colin <colin> 1.4.13-3.mga3
+ Revision: 273742
- Add tmpfiles.d config to create PID dir
- Drop sysvinit script

* Fri Jun 08 2012 shlomif <shlomif> 1.4.13-2.mga3
+ Revision: 257589
- Bump release
- Convert tabs to spaces (rpmlint)
- Got rid of trailing space

* Fri Jun 08 2012 shlomif <shlomif> 1.4.13-1.mga3
+ Revision: 257582
- New version - 1.4.13
+ colin <colin>
- Implement a systemd target to easily control all memcache instances

* Sat Apr 28 2012 tmb <tmb> 1.4.11-3.mga2
+ Revision: 233790
- Require rpm-helper >= 0.24.8-1 for systemd support

* Mon Apr 02 2012 colin <colin> 1.4.11-2.mga2
+ Revision: 227942
- Bring sysconfig file and initscript into sync
- Add systemd (template) unit

* Tue Jan 31 2012 dmorgan <dmorgan> 1.4.11-1.mga2
+ Revision: 203721
- New version 1.4.11
  Disable sasl support ( need to fix build )
  Disable tests ( need to be fixed )

* Mon Jan 24 2011 erwan <erwan> 1.4.5-6.mga1
+ Revision: 37960
- imported package memcached


* Sun Jan 02 2011 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-6mdv2011.0
+ Revision: 627635
- don't force the usage of automake1.7

* Wed Dec 22 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-5mdv2011.0
+ Revision: 623867
- rebuilt against libevent 2.x

* Wed Nov 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.5-4mdv2011.0
+ Revision: 598316
- fix build (fedora)

* Mon May 03 2010 Colin Guthrie <cguthrie@mandriva.org> 1.4.5-3mdv2010.1
+ Revision: 541718
- Fix typo and program name in status output
- Rewrite init script to support multiple instances.
- Fix the case where you want memcached to listen on all network interfaces

* Thu Apr 22 2010 Colin Guthrie <cguthrie@mandriva.org> 1.4.5-1mdv2010.1
+ Revision: 537935
- New version: 1.4.5
- Disable test profiling as it seems to break build.
- Remove check for daemon binary in init script. It's part of the same package.

* Tue Feb 23 2010 Per Øyvind Karlsen <peroyvind@mandriva.org> 1.4.4-2mdv2010.1
+ Revision: 509869
- add missing buildrequires required for test suite and enable it as well
- fix incorrect group for devel package
- fix > 80 character width description for -devel package
- rewrite init script
- don't enable unix sockets / disable networking by default anymore
- cleaned up spec

* Wed Dec 09 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-1mdv2010.1
+ Revision: 475222
- 1.4.4

* Sun Nov 08 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.3-1mdv2010.1
+ Revision: 462976
- 1.4.3
- new url
- simplify the initscript and config file
- fix deps

* Sun Oct 25 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.2-1mdv2010.0
+ Revision: 459200
- 1.4.2

* Sat Sep 19 2009 Oden Eriksson <oeriksson@mandriva.com> 1.4.1-1mdv2010.0
+ Revision: 444621
- 1.4.1
- drop repcached. maybe reintroduce it later

* Sun Jun 07 2009 Oden Eriksson <oeriksson@mandriva.com> 1.2.8-1mdv2010.0
+ Revision: 383709
- 1.2.8
- repcached-2.2-1.2.8
- drop upstream patches
- temporary disable "make test"
- fix deps

* Mon May 04 2009 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-5mdv2010.0
+ Revision: 371632
- P1: security fix for CVE-2009-1255

* Mon Jan 05 2009 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-4mdv2009.1
+ Revision: 325075
- repcached-2.2

* Wed Dec 17 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-3mdv2009.1
+ Revision: 315234
- rebuild

* Wed Aug 27 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-2mdv2009.0
+ Revision: 276664
- repcached-2.1

* Sun Aug 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.6-1mdv2009.0
+ Revision: 270210
- 1.2.6
- rediffed the latest repcached-2.0 patch

* Sat Jun 28 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.5-3mdv2009.0
+ Revision: 229679
- hardcode %%{_localstatedir}

  + Pixel <pixel@mandriva.com>
    - adapt to %%_localstatedir now being /var instead of /var/lib (#22312)

* Wed May 14 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.5-2mdv2009.0
+ Revision: 207045
- rebuilt against libevent-1.4.4

* Thu Apr 10 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.5-1mdv2009.0
+ Revision: 192539
- 1.2.5
- rediffed and adjusted repcached-1.2-1.2.4.patch slightly
- fix lib64 stuff
- use --enable-64bit on x86_64

* Thu Feb 21 2008 Oden Eriksson <oeriksson@mandriva.com> 1.2.4-1mdv2008.1
+ Revision: 173417
- 1.2.4
- new repcached patch (1.1)
- drop upstream implemented patches

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Nov 16 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-2mdv2008.1
+ Revision: 109084
- added upstream socket permission fix (P0)
- added replication support (P1)
- added pid file generation fix from fedora (P2)
- major initscript and config rework

* Wed Aug 22 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.3-1mdv2008.0
+ Revision: 68952
- 1.2.3

* Mon Jul 16 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.2-2mdv2008.0
+ Revision: 52533
- use the %%serverbuild macro

* Sat May 19 2007 David Walluck <walluck@mandriva.org> 1.2.2-1mdv2008.0
+ Revision: 28446
- 1.2.2
- LSB-complaint and MDV-complaint initscript

* Fri Apr 27 2007 Oden Eriksson <oeriksson@mandriva.com> 1.2.1-1mdv2008.0
+ Revision: 18625
- 1.2.1


* Tue Dec 19 2006 Oden Eriksson <oeriksson@mandriva.com> 1.2.0-3mdv2007.0
+ Revision: 100284
- release bump due to #27632
- fix deps (libnet1.1.2-devel)
- fix deps (perl-devel)
- rebuild
- 1.2.0
- fix deps
- bunzip sources
- Import memcached

* Sat Jun 03 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-4mdv2007.0
- fix deps

* Mon Apr 17 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-3mdk
* Fri Mar 17 2006 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-2mdk
- rebuilt against libnet1.1.2

* Sat Nov 26 2005 Oden Eriksson <oeriksson@mandriva.com> 1.1.12-1mdk
- 1.1.12
- fix deps

* Wed May 11 2005 Thierry Vignaud <tvignaud@mandrakesoft.com> 1.1.11-2mdk
- add prereq on rpm-helper
- rebuild for new libevent

* Sun Jan 23 2005 Oden Eriksson <oeriksson@mandrakesoft.com> 1.1.11-1mdk
- initial Mandrakelinux package

